dataset: Load Dataset

View source: R/dataset.R

datasetR Documentation

Load Dataset

Description

This function loads a dataset that is not included in the package due to space constraints on CRAN, but is available online from GitHub. It works similarly to the R command data from the utils package, except that it downloads the dataset.

Usage

dataset(name)

Arguments

name

a string containing the link.

Examples

## Download data
dataset("thefts")
head(thefts)
summary(thefts)
## for details on the dataset type
?thefts

DATAstudio documentation built on Feb. 6, 2026, 9:07 a.m.