Learn R Programming

DATAstudio (version 1.2.3)

earthquake_tsunami: Earthquake-Tsunami Data

Description

The earthquake_tsunami dataset consists of point process data on earthquake locations (latitude and longitude) dating back to 2150 B.C., together with an indicator of whether the event was followed by a tsunami.

Usage

earthquake_tsunami

Arguments

Format

The earthquake_tsunami data frame contains the following columns:

tsunami

Indicator of tsunami occurrence (1 = yes, 0 = no).

latitude

Epicentral latitude (º).

longitude

Epicentral longitude (º).

magnitude

Earthquake magnitude (Richter scale).

focal

Focal depth of the earthquake (km).

References

de Carvalho, M., Ferrer, C. & Vallejos, R. (2026, to appear). A Kolmogorov–Arnold neural model for cascading extremes. Extremes.