| faang | R Documentation |
Daily information on FAANG stocks.
The faang object is a list with five elements, each containing
a matrix with columns corresponding to the opening, highest, lowest,
and closing prices, as well as trading volume and adjusted closing
price.
To load the file use the command dataset("faang").
FAANG is an acronym for popular tech stocks, namely (Meta’s) Facebook,
Apple, Amazon, Netflix, and (Alphabet’s) Google. The data consist of
prices at close for these stocks over 2012-2024. The data were
gathered from Yahoo Finance.
de Carvalho, M. and Palacios Ramirez, K. (2025) Semiparametric Bayesian modeling of nonstationary joint extremes: How do big tech's extreme losses behave? Journal of the Royal Statistical Society, Ser. C, 74, 447-465.
## Not run:
dataset("faang")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.