| wildfire | R Documentation |
The wildfire data from Portugal contains daily burnt area (in
hectares) for wildfires in Portugal, and Canadian Forest Fire Weather
Index System indices between 1980 to 2019.
wildfire
wildfire is a data frame with 14609 occurances (rows) and 11
variables (columns).
The wildfire data frame contains the following columns:
Burnt_Area: daily burnt area in hectares.
DSR: Daily Severity Rating (DSR), a numeric rating of the difficulty of controlling fires.
FWI: Fire Weather Index (FWI), a numeric rating of fire intensity.
BUI: Buildup Index (BUI), a numeric rating of the total amount of fuel available for combustion.
ISI: Initial Spread Index (ISI), a numeric rating of the expected rate of fire spread.
FFMC: Fine Fuel Moisture Code (FFMC), a numeric rating of the moisture content of litter and other cured fine fuels.
DMC: Duff Moisture Code (DMC), a numeric rating of the average moisture content of loosely compacted organic layers of moderate depth.
DC: Drought Code (DC), a rating of the average moisture content of deep, compact organic layers.
day, month, year: timestamp to date for each datapoints.
Instituto Dom Luiz
Lee, M. W., de Carvalho, M., Paulin, D., Pereira, S., Trigo, R., and da Camara, C. (2026). BLAST: A Bayesian lasso tail index regression model with an application to extreme wildfires. Submitted.
## preview of the data
data(wildfire)
head(wildfire, 10)
summary(wildfire)
## Not run:
require(ggplot2)
## visualizing the data by month
ggplot(wildfire, aes(x = month, y = Burnt_Area, color = month)) +
geom_point(size = 3) +
xlab("Month") +
ylab("Burnt Area (ha)") +
theme_minimal()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.