| dataset | R Documentation |
This function loads a dataset that is not included in the package due
to space constraints on CRAN, but is available online from GitHub.
It works similarly to the R command data
from the utils package, except that it downloads the dataset.
dataset(name)
name |
a string containing the link. |
## Download data
dataset("thefts")
head(thefts)
summary(thefts)
## for details on the dataset type
?thefts
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.